.. _url_redirection_module:

:mod:`cubicweb.pyramid.url_redirection`
---------------------------------------

.. automodule:: cubicweb.pyramid.url_redirection

    .. autofunction:: includeme

    .. autofunction:: add_redirection_rule

    .. autofunction:: url_redirection_tween_factory
